'use strict';

var exec = require('child_process').exec;
var execSync = require('child_process').execSync;

var isUsingWindows = process.platform == 'win32'

var commandExistsUnix = function(commandName, callback) {
  var child = exec('command -v ' + commandName +
        ' 2>/dev/null' +
        ' && { echo >&1 \'' + commandName + ' found\'; exit 0; }',
        function (error, stdout, stderr) {
            callback(null, !!stdout);
        });
}

var commandExistsWindows = function(commandName, callback) {
  var child = exec('where ' + commandName,
    function (error) {
      if (error !== null){
        callback(null, false);
      } else {
        callback(null, true);
      }
    }
  )
}

var commandExistsUnixSync = function(commandName) {
  try {
    var stdout = execSync('command -v ' + commandName +
          ' 2>/dev/null' +
          ' && { echo >&1 \'' + commandName + ' found\'; exit 0; }'
          );
    return !!stdout;
  } catch (error) {
    return false;
  }
}

var commandExistsWindowsSync = function(commandName, callback) {
  try {
      var stdout = execSync('where ' + commandName);
      return !!stdout;
  } catch (error) {
      return false;
  }
}

module.exports = function(commandName, callback) {
  if (isUsingWindows) {
    commandExistsWindows(commandName, callback);
  } else {
    commandExistsUnix(commandName, callback);
  }
};

module.exports.sync = function(commandName) {
  if (isUsingWindows) {
    return commandExistsWindowsSync(commandName);
  } else {
    return commandExistsUnixSync(commandName);
  }
};
